=========
Changelog
=========

Version 0.3.7
=============

- Fix issue #28, reading from non-existing cell

Version 0.3.6
=============

- Add exception handling for opening a files
- Add lon, lat information in writing operation of GriddedBase

Version 0.3.5
=============

- Remove unnecessary dependencies and improve documentation.

Version 0.3.4
=============

- Add conda requirements file
- Add object base classes for time series and image
- Add image base and multitemporal-image base classes

Version 0.3.3
=============

- Update requirements

Version 0.3.2
=============

- Add ImageBase class (moved from pytesmo)
- Fixing documentation

Version 0.3.1
=============

- Updating pyscaffold version to 

Version 0.3.0
=============

- New GriddedBase class
- Slight changes in the method names

Version 0.2.0
=============

- Support of ioclass keyword arguments
- Fix iteration inconsistency

Version 0.1
===========

- First developer release
